<template>
  <div class="app-container">
    <div class="filter-container">
      <el-input v-model="listQuery.keyword" size="small" placeholder="请输入编号/名称" clearable class="filter-item w-200" />
      <el-button-group class="filter-item">
        <el-button size="small" type="primary" icon="el-icon-search" @click="search">
          搜索
        </el-button>
        <el-button size="small" type="primary" icon="el-icon-refresh" @click="refresh">
          刷新
        </el-button>
        <el-button v-if="uadd=='Yes'" size="small" type="primary" icon="el-icon-plus" @click="add">
          新增
        </el-button>
      </el-button-group>
    </div>

    <el-table v-loading="listLoading" :data="list" element-loading-text="Loading" border fit height="100%"
      class="table-container" highlight-current-row>
      <el-table-column fixed label="序号" width="80" >
        <template slot-scope="scope">
          {{ scope.row.id }}
        </template>
      </el-table-column>
      <el-table-column label="设备ID" >
        <template slot-scope="scope">
          {{ scope.row.tagid }}
        </template>
      </el-table-column>
      <el-table-column label="名称" >
        <template slot-scope="scope">
          {{ scope.row.alarmname }}
        </template>
      </el-table-column>
      <el-table-column label="公司"  width="180">
        <template slot-scope="scope">
          {{ scope.row.company }}
        </template>
      </el-table-column>
      <el-table-column label="天阈值" >
        <template slot-scope="scope">
          {{ scope.row.hdsv}}
        </template>
      </el-table-column>
      <el-table-column label="北阈值" >
        <template slot-scope="scope">
          {{ scope.row.ndsv}}
        </template>
      </el-table-column>
      <el-table-column label="东阈值" >
        <template slot-scope="scope">
          {{ scope.row.edsv}}
        </template>
      </el-table-column>
      <el-table-column  label="操作" width="200"  v-if="uupdate=='Yes' || udelete=='Yes'">
        <template slot-scope="scope">
          <el-button-group>
            <el-button v-if="uupdate=='Yes'" type="primary" icon="el-icon-edit" size="mini" @click="edit(scope)">
              修改
            </el-button>
            <el-button v-if="udelete=='Yes'" type="danger" icon="el-icon-delete" size="mini" @click="del(scope)">
              删除
            </el-button>
          </el-button-group>
        </template>
      </el-table-column>
    </el-table>

    <pagination v-show="total > 0" :total="total" :page.sync="listQuery.current" :limit.sync="listQuery.size"
      @pagination="fetchData" />

    <el-dialog :visible.sync="dialogVisible" :title="dialogType === 'modify' ? '修改' : '新增'">
      <el-form :ref="temp" :model="temp" label-width="120px" label-position="right" :rules="rules">
        <el-form-item label="设备ID" prop="tagid">
          <el-input v-model="temp.tagid
        " placeholder="请输入设备ID" />
        </el-form-item>
        <el-form-item label="名称" prop="alarmname">
          <el-input v-model="temp.alarmname
        " placeholder="请输入名称" />
        </el-form-item>
        <el-form-item label="公司" prop="companyid">
          <el-select style="width: 100%;" v-model="temp.companyid" filterable remote placeholder="请输入关键词"
            :remote-method="searchMethod" :loading="searchloading">
            <el-option v-for="item in options" :key="item.id" :label="item.companyname" :value="item.id">
            </el-option>
          </el-select>
        </el-form-item>
        <el-form-item label="东位移预警值" prop="hdsv">
          <el-input v-model="temp.hdsv
        " placeholder="请输入东位移预警值" type="number"/>
        </el-form-item>
        <el-form-item label="北位移预警值" prop="ndsv">
          <el-input v-model="temp.ndsv
        " placeholder="请输入北位移预警值" type="number"/>
        </el-form-item>
        <el-form-item label="天位移预警值" prop="edsv">
          <el-input v-model="temp.edsv
        " placeholder="请输入天位移预警值" type="number"/>
        </el-form-item>
      </el-form>
      <div class="text-right">
        <el-button type="danger" @click="dialogVisible = false">
          取消
        </el-button>
        <el-button type="primary" @click="submit">
          确定
        </el-button>
      </div>
    </el-dialog>
  </div>
</template>

<script>
import Pagination from '@/components/Pagination'
import { getAlarmsystemPage, delAlarmsystem, addorupAlarmsystem, search,searchAlarmsystem,addSystemOperationLog } from '@/api/threshold'
import { deepClone } from '@/utils'

const _temp = {
  id: '',
  hdsv: '',
  tagid: '',
  ndsv: '',
  edsv: '',
  companyid: '',
  alarmname:'',
}

export default {
  components: {
    Pagination
  },
  data() {
    return {
      uadd:'',
      udelete:'',
      uupdate:'',
      total: 0,
      list: [],
      menus: [],
      options: [],
      searchloading: false,
      listLoading: true,
      listQuery: {
        username: localStorage.getItem('username') || '',
        current: 1,
        size: 20,
        keyword: undefined,
      },
      uploadUrl: '',
      temp: Object.assign({}, _temp),
      dialogVisible: false,
      dialogType: 'create',
      loading: false,
      rules: {
        tagid: [
            { required: true, message: '请输入设备ID', trigger: 'blur' },
          ],
          alarmname: [
            { required: true, message: '请输入名称', trigger: 'blur' },
          ],
          companyid: [
            {  required: true, message: '请选择公司', trigger: 'change' }
          ],
          hdsv: [
            { required: true, message: '请输入东位移预警值', trigger: 'blur' }
          ],
          edsv: [
            {  required: true, message: '请输入天位移预警值', trigger: 'change' }
          ],
          ndsv: [
            {  required: true, message: '请输入北位移预警值', trigger: 'blur' }
          ]
        },
    }
  },
  created() {
    this.fetchData()
  },
  methods: {
     // 远程搜索
     searchMethod(query) {
      if (query !== '') {
        this.loading = true;
        var params = { query: query }
        search(params).then(response => {
          this.options = response.data;
          this.loading = false;
        })
      } else {
        this.options = [];
      }
    },
    // 搜索
    search() {
      this.listLoading = true
      searchAlarmsystem(this.listQuery).then(response => {
        if (response.data!=null) {
          this.list = response.data.records
          this.total = response.data.total
        }else{
          this.$message({
            message: '未搜索到数据',
            type: 'error'
          })
        }
      
        this.listLoading = false
      })
    },
    refresh() {
      this.listQuery = {
        username: localStorage.getItem('username') || '',
        current: 1,
        size: 20,
        keyword: undefined
      }
      this.fetchData()
    },
    // 分页数据
    fetchData() {
      this.uadd = localStorage.getItem('uadd') || '';
      this.udelete = localStorage.getItem('udelete') || '';
      this.uupdate = localStorage.getItem('uupdate') || '';
      this.listLoading = true
      getAlarmsystemPage(this.listQuery).then(response => {
        this.list = response.data.records
        this.total = response.data.total
        this.listLoading = false
      })
    },
    resetTemp() {
      this.temp = Object.assign({}, _temp)
    },
    add() {
      this.resetTemp()
      this.dialogVisible = true
      this.dialogType = 'create'
      // this.$nextTick(() => {
      //   this.$refs['dataForm'].clearValidate()
      // })
    },
    edit(scope) {
      this.resetTemp()
      this.dialogVisible = true
      this.dialogType = 'modify'
      this.temp = deepClone(scope.row)
      // this.$nextTick(() => {
      //   this.$refs['dataForm'].clearValidate()
      // })
    },
    changeStatus(value, scope) {
      setTimeout(() => {
        this.list[scope.$index].status = value
        this.$message({
          message: '更新成功',
          type: 'success'
        })
      }, 300)
    },
    // 删除
    del(scope) {
      this.$confirm('确认删除该条数据吗？', '提示', {
        confirmButtonText: '确定',
        cancelButtonText: '取消',
        type: 'warning'
      }).then(() => {
        setTimeout(() => {
          const params = { id: scope.row.id };
          this.list.splice(scope.$index, 1)
          delAlarmsystem(params).then(response => {
            this.temp.adminname = localStorage.getItem('username') || '';
            const params = { name:  this.temp.adminname, content: '删除了一个报警阈值，该设备id为：'+scope.row.tagid };
            addSystemOperationLog(params).then(response => {

                        })
            this.$message({
              message: '删除成功',
              type: 'success'
            })
            this.fetchData()
          })
        }, 300)
      })
    },
    submit() {
      if (this.loading) {
        return
      }
      this.loading = true
      this.$refs[this.temp].validate((valid) => {
        if (valid) {
      addorupAlarmsystem(this.temp).then(() => {
        if (this.temp.id=="") {
          this.temp.adminname = localStorage.getItem('username') || '';
            const params = { name:  this.temp.adminname, content: '新增了一个报警阈值，该设备id为：'+this.temp.tagid };
            addSystemOperationLog(params).then(response => {

                        })
        } else {
          this.temp.adminname = localStorage.getItem('username') || '';
            const params = { name:  this.temp.adminname, content: '修改了一个报警阈值，该设备id为：'+this.temp.tagid };
            addSystemOperationLog(params).then(response => {

                        })
        }
        this.fetchData()

        setTimeout(() => {
          this.$message({
            message: '提交成功',
            type: 'success'
          })
          this.dialogVisible = false
          this.loading = false
        }, 300)
      })
    } else {
            this.$message({
            message: '提交失败，请检查表单必填项是否为空',
            type: 'error'
          })
            console.log('error submit!!');
            return false;
          }
        });
    }
  }
}
</script>

<style lang="scss" scoped>
.el-upload {
  border: 1px dashed #d9d9d9 !important;
  border-radius: 6px;
  cursor: pointer;
  position: relative;
  overflow: hidden;

  .el-icon-plus.avatar-uploader-icon {
    border: 1px dashed #d9d9d9 !important;
    border-radius: 6px;
    font-size: 28px;
    color: #8c939d;
    width: 128px;
    height: 128px;
    line-height: 128px;
    text-align: center;
  }
}

.avatar-uploader {
  height: 128px;

  img {
    width: 128px;
    height: 128px;
  }
}
</style>
